@@ -57,8 +57,7 @@ class KUserProxy : public QObject
 
 public:
     KUserProxy(QObject *parent = nullptr);
-    ~KUserProxy();
-
+    ~KUserProxy() override;
 
     /**
      * @return the full name of the user
@@ -112,5 +111,4 @@ private:
     bool m_temporaryEmptyFaceIconPath;
 };
 
-#endif //KUSERPROXY_H
-
+#endif // KUSERPROXY_H
