@@ -28,17 +28,21 @@ public:
     QList<QPointer<KCoreConfigSkeleton>> _skeletons;
 };
 
+#if QUICKADDONS_BUILD_DEPRECATED_SINCE(5, 88)
 ManagedConfigModule::ManagedConfigModule(const KAboutData *aboutData, QObject *parent, const QVariantList &args)
     : ConfigModule(aboutData, parent, args)
     , d(new ManagedConfigModulePrivate(this))
 {
 }
+#endif
 
+#if QUICKADDONS_BUILD_DEPRECATED_SINCE(5, 88)
 ManagedConfigModule::ManagedConfigModule(const KPluginMetaData &metaData, QObject *parent, const QVariantList &args)
     : ConfigModule(metaData, parent, args)
     , d(new ManagedConfigModulePrivate(this))
 {
 }
+#endif
 
 ManagedConfigModule::ManagedConfigModule(QObject *parent, const QVariantList &args)
     : ConfigModule(parent, args)
@@ -46,6 +50,12 @@ ManagedConfigModule::ManagedConfigModule(QObject *parent, const QVariantList &ar
 {
 }
 
+ManagedConfigModule::ManagedConfigModule(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : ConfigModule(parent, metaData, args)
+    , d(new ManagedConfigModulePrivate(this))
+{
+}
+
 ManagedConfigModule::~ManagedConfigModule()
 {
     delete d;
